
#include "stdafx.h"
#include "_gpio.h" 
//#include "private_xwboardsdk.h"

/*
 WP-5000 series allows the GPIO pin below to be user defined pin for XWBoard bus
 
   GPIO 11 - 48MHz Clock
   GPIO 16
   GPIO 17
   GPIO 81
   GPIO 86
   GPIO 87
   GPIO 117
   GPIO 118
*/
/*typedef volatile struct
{
    DWORD    pwmcr0;
    DWORD    pwmdcr0;
    DWORD    pwmpcr0;
    DWORD    reserved;
    DWORD    pwmcr2;
    DWORD    pwmdcr2;
    DWORD    pwmpcr2;
}PWM_REGS_T;*/

//GPIO========================================================================
#define PAC_ERR_GPIO_BASE					0x21000
#define PAC_ERR_GPIO_DIRECTION				(PAC_ERR_GPIO_BASE + 1)
#define PAC_ERR_GPIO_ILLEGAL_PIN			(PAC_ERR_GPIO_BASE + 2)
#define	PAC_ERR_GPIO_ILLEGAL_PWM_PIN		(PAC_ERR_GPIO_BASE + 3)

#define XWBUS_GPIO11	11 //GPIO pin 11
#define XWBUS_GPIO16	16 //GPIO pin 16
#define XWBUS_GPIO17	17 //GPIO pin 17
#define XWBUS_GPIO81	81 //GPIO pin 81
#define XWBUS_GPIO86	86 //GPIO pin 86
#define XWBUS_GPIO87	87 //GPIO pin 87
#define XWBUS_GPIO117	117 //GPIO pin 117
#define XWBUS_GPIO118	118 //GPIO pin 118

bool Check_XWBus_Pin(unsigned int pin)
{
	switch(pin)
	{
		case XWBUS_GPIO11: //GPIO pin 11
		case XWBUS_GPIO16: //GPIO pin 16
		case XWBUS_GPIO17: //GPIO pin 17
		case XWBUS_GPIO81: //GPIO pin 81
		case XWBUS_GPIO86: //GPIO pin 86
		case XWBUS_GPIO87: //GPIO pin 87
		case XWBUS_GPIO117: //GPIO pin 117
		case XWBUS_GPIO118: //GPIO pin 118
			return true;
		default:
			SetLastError(PAC_ERR_GPIO_ILLEGAL_PIN);
			return false;
	}	
}

 int Get_GPIO_Pin_Status(unsigned int pin)
{
/* 
Get the status of the GPIO input pin
 	Pin:
		11: GPIO 11 - 48MHz Clock
		16: GPIO 16
		17: GPIO 17
		81: GPIO 81
		86: GPIO 86
		87: GPIO 87
		117: GPIO 117
		118: GPIO 118
*/
	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;
//    XLLP_UINT32_T list[1][2];

	if(Check_XWBus_Pin(pin)==false)
	{		
		return -1;
	}

//	list[0][0]=1;
//	list[0][1]=pin;

//	XllpGpioSetDirectionOut(p_GPIORegs, list[0]);
	if(XllpGpioGetDirection(p_GPIORegs,pin))//Error, pin must be configured as input
	{
		SetLastError(PAC_ERR_GPIO_DIRECTION);
		return -1;
	}
	return XllpGpioGetState(p_GPIORegs,pin);
}

 void Set_GPIO_Pin_Status(unsigned int pin, unsigned int value)
{
/* 
Set GPIO output pin to high or low level
 	Pin:
		11: GPIO 11 - 48MHz Clock
		16: GPIO 16
		17: GPIO 17
		81: GPIO 81
		86: GPIO 86
		87: GPIO 87
		117: GPIO 117
		118: GPIO 118
	value:
		0: output 0
		1: output 1
*/

	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;
    XLLP_UINT32_T list[1][2];

	if(Check_XWBus_Pin(pin)==false)
		return ;

	list[0][0]=1;
	list[0][1]=pin;

//	XllpGpioSetDirectionOut(p_GPIORegs, list[0]);
	if(!XllpGpioGetDirection(p_GPIORegs,pin))//pin must be configured as output
	{
		SetLastError(PAC_ERR_GPIO_DIRECTION);
		return ;
	}

	if (value) 
		XllpGpioSetOutputState1(p_GPIORegs, list[0]);
	else
		XllpGpioSetOutput0(p_GPIORegs, list[0]);
}

 void setGPIOInput(unsigned int pin) 
/* 
GPIO pin configured as an input
 	Pin:
		11: GPIO 11 - 48MHz Clock
		16: GPIO 16
		17: GPIO 17
		81: GPIO 81
		86: GPIO 86
		87: GPIO 87
		117: GPIO 117
		118: GPIO 118
*/
{	
	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;
    XLLP_UINT32_T list[1][2];
    XLLP_UINT32_T value[] = {1, 0};

	if(Check_XWBus_Pin(pin)==false)
		return ;

	list[0][0]=1;
	list[0][1]=pin;

    XllpGpioSetAlternateFn(p_GPIORegs, list[0], value);
	XllpGpioSetDirectionIn(p_GPIORegs, list[0]);
//    XllpGpioSetDirectionOut(p_GPIORegs, list[index]);

/*	if (bFlag) 
		XllpGpioSetOutputState1(p_GPIORegs, list[index]);
	else
		XllpGpioSetOutput0(p_GPIORegs, list[index]);*/
}

 void setGPIOOutput(unsigned int pin, unsigned int value)
/* 
GPIO pin configured as an output
 	Pin:
		11: GPIO 11 - 48MHz Clock
		16: GPIO 16
		17: GPIO 17
		81: GPIO 81
		86: GPIO 86
		87: GPIO 87
		117: GPIO 117
		118: GPIO 118
	value:
		0: output 0
		1: output 1
*/
{
	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;

    XLLP_UINT32_T list[1][2];
    XLLP_UINT32_T Fnvalue[] = {1, 0};

	if(Check_XWBus_Pin(pin)==false)
		return ;

	list[0][0]=1;
	list[0][1]=pin;

    XllpGpioSetAlternateFn(p_GPIORegs, list[0], Fnvalue);
	XllpGpioSetDirectionOut(p_GPIORegs, list[0]);
	if (value) 
		XllpGpioSetOutputState1(p_GPIORegs, list[0]);
	else
		XllpGpioSetOutput0(p_GPIORegs, list[0]);
}

 void setGPIOAltFunc(unsigned int pin, unsigned int af, unsigned int mode)
/*
	Set GPIO alternate function
	Pin:
		11: GPIO 11 - 48MHz Clock
		16: GPIO 16
		17: GPIO 17
		81: GPIO 81
		86: GPIO 86
		87: GPIO 87
		117: GPIO 117
		118: GPIO 118	  
	af:
		0 : Alternate Function 0 -->The corresponding GPIO pin is used for as a general purpose I/O
		1 : Alternate Function 1 -->The corresponding GPIO pin is used for its alternate function 1
		2 : Alternate Function 2 -->The corresponding GPIO pin is used for its alternate function 2
		3 : Alternate Function 3 -->The corresponding GPIO pin is used for its alternate function 3
	
	 mode:
		0: output mode
		1: input mode

*/
{
	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;
    XLLP_UINT32_T list[1][2];
    XLLP_UINT32_T value[2]; // = {1, 0};

	if(Check_XWBus_Pin(pin)==false)
		return ;

	list[0][0]=1;
	list[0][1]=pin;
	
	value[0]=1;
	value[1]=af;

    XllpGpioSetAlternateFn(p_GPIORegs, list[0], value);

	if(mode)
		XllpGpioSetDirectionIn(p_GPIORegs, list[0]);
	else
	    XllpGpioSetDirectionOut(p_GPIORegs, list[0]);
}

 void setGPIO11_ClockOut(unsigned int Enable)
/*
 Set GPIO11 to genernate 48M Hz clock output .
 Enable:
	1: Enable Clock output
	0: Disable Clock output
*/ 
{
	XLLP_GPIO_T *p_GPIORegs = (XLLP_GPIO_T *)GPIO_BASE_U_VIRTUAL;

    XLLP_UINT32_T list[1][2] ={{1,11}}; //=> pin 11
    XLLP_UINT32_T value[] = {1, 3}; //Fn =>3 

		
    XllpGpioSetAlternateFn(p_GPIORegs, list[0], value);
	if(Enable)
		XllpGpioSetDirectionOut(p_GPIORegs, list[0]);
	else
		XllpGpioSetDirectionIn(p_GPIORegs, list[0]);
}

void SetPWM_GPIO16(int mode) //(WORD pinNum)
{
	setGPIOAltFunc(16,2,mode);
}
void SetPWM_GPIO17(int mode) //(WORD pinNum)
{
	setGPIOAltFunc(17,2,mode);
}


#define PWM_FREQ 20000 //20K Hz for Backlight

void SetFreq_duty(PWM_REGS_T* pPWMRegs,DWORD dwFrequency,int duty)
{
	int val;

	if(!dwFrequency)
		dwFrequency=PWM_FREQ;

	pPWMRegs->pwmcr0= (1<<6) | (63);
	val = (2031250 / dwFrequency + 5) / 10;
		
	pPWMRegs->pwmpcr0=val;
	pPWMRegs->pwmdcr0=(val * duty) / 100;		
}

 void setGPIO_PWM(unsigned int pin,DWORD dwFrequency,unsigned int Duty,int Enable)
/*
 Set GPIO16/17 to genernate PWM signal output .
 	Pin:
		16: GPIO 16
		17: GPIO 17
	dwFrequency:
		PWM frequency
	Duty:
		0~100 %
	Enable:
	   1: enable
	   0: disalbe

*/
{
	
	PWM_REGS_T* pPWMRegs;

	if(pin!=16 && pin!=17)
	{
		SetLastError(PAC_ERR_GPIO_ILLEGAL_PWM_PIN);		
		return ;
	}
	if(pin==16)
	{
		SetPWM_GPIO16(Enable);
		if(Enable)
		{			
			pPWMRegs = (PWM_REGS_T *)PWM0_2_BASE_U_VIRTUAL;
			SetFreq_duty(pPWMRegs,dwFrequency,  Duty);
		}		
	}
	else if(pin==17)
	{
		SetPWM_GPIO17(Enable);
		if(Enable)
		{			
			pPWMRegs = (PWM_REGS_T *)PWM1_3_BASE_U_VIRTUAL;
			SetFreq_duty(pPWMRegs,dwFrequency, Duty);
		}		
	}

}
