#ifndef __XW304_H
#define __XW304_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef XW304_EXPORTS
#define XW304_API extern "C" __declspec(dllexport) 
#else
#define XW304_API extern "C" __declspec(dllimport) 
#endif

#define XW304_DigitalIn      XW304_Read_All_DI
#define XW304_DigitalOut     XW304_Write_All_DO

XW304_API int XW304_Init(void);
/*  Return value: 0   ==> success
    Return value: <>0 ==> error
    Bit0: 1 ==> Reads A/D Gain falure
    Bit1: 1 ==> Reads A/D Offset falure
    Bit2: 1 ==> Reads D/A Gain falure
    Bit3: 1 ==> Reads D/A Offset falure
    Bit4: 1 ==> WX304 board cannot be found */

XW304_API unsigned XW304_GetLibVersion(void);
/*  Current version is 1.00 (return 0x0100) */

XW304_API float XW304_Read_AD_CalibrationGain(int AI_TYPE);//AI_TYPE 0->+-5V,  1->0~5V
/*  Return 10.0 if no setting in EEPROM   */

XW304_API float XW304_Read_AD_CalibrationOffset(int AI_TYPE);
/*  Return 10.0 if no setting in EEPROM   */

XW304_API float XW304_Read_DA_CalibrationGain(void);
/*  Return 10.0 if no setting in EEPROM   */

XW304_API float XW304_Read_DA_CalibrationOffset(void);
/*  Return 10.0 if no setting in EEPROM   */

XW304_API float XW304_AnalogIn(int iChannel,int AI_TYPE);
/*  iChannel: 0~5   */

XW304_API void XW304_AnalogOut(float fValue);
/*  fValue: -5.0 ~ 5.0  */

XW304_API int XW304_Read_All_DI(void);
/*  Return data = 0x00~0x0F
    Return 1 => open
                Logic high level (+3.5V ~ +30V)
    Return 0 => close to GND
    Logic low level (0V ~ +1V)  */

XW304_API int XW304_Read_One_DI(int iChannel);
/*  iChannel = 0 ~ 3
    Return 1 => open
                Logic high level (+3.5V ~ +30V)
    Return 0 => close to GND
                Logic low level (0V ~ +1V)  */

XW304_API void XW304_Write_All_DO(int iOutValue);
/*  iOutValue: 0x00 ~ 0x0f  */

XW304_API void XW304_Write_One_DO(int iChannel, int iStatus);
/*  iChannel = 0 ~ 3
    iStatus = 1 => Status is ON
    iStatus = 0 => Status is OFF    */

XW304_API int XW304_Read_All_DO(void);
/*  Return data = 0x00~0x0f */

XW304_API int XW304_Read_One_DO(int iChannel);
/*  iChannel = 0 ~ 3
    Return  1 => ON
    Return  0 => OFF    */

XW304_API void XW304_SetDelay(int Delayms);
XW304_API int XW304_GetDelay(void);

XW304_API void XW304_AnanlogInSetChannel(int iChannel);
XW304_API int XW304_AnalogInHex(void);
XW304_API float XW304_AnalogInHexToFloat(int iValue,int AI_TYPE);
XW304_API void Cslow(void);
XW304_API void usWait(unsigned usVal);
extern float    XW304_fAD_Gain[2], XW304_fAD_Offset[2];
extern float    XW304_fDA_Gain, XW304_fDA_Offset;

#ifdef __cplusplus
}
#endif

#endif
