#ifndef __XW310_H
#define __XW310_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef XW310_EXPORTS
#define XW310_API extern "C" __declspec(dllexport) 
#else
#define XW310_API extern "C" __declspec(dllimport) 
#endif

#define XW310_DigitalIn      XW310_Read_All_DI
#define XW310_DigitalOut     XW310_Write_All_DO

void XW310_AOInit(void);

XW310_API int XW310_Init(void);
/*  Return value: 0   ==> success
    Return value: <>0 ==> error
    Bit0: 1 ==> Reads A/D Gain falure
    Bit1: 1 ==> Reads A/D Offset falure
    Bit2: 1 ==> Reads D/A Gain falure
    Bit3: 1 ==> Reads D/A Offset falure
    Bit4: 1 ==> WX304 board cannot be found */
XW310_API unsigned XW310_GetLibVersion(void);
/*  Current version is 1.00 (return 0x0100) */

XW310_API float XW310_Read_AD_CalibrationGain(void);
/*  Return 10.0 if no setting in EEPROM   */

XW310_API float XW310_Read_AD_CalibrationOffset(void);
/*  Return 10.0 if no setting in EEPROM   */

XW310_API float XW310_Read_DA_CalibrationGain(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310_API float XW310_Read_DA_CalibrationOffset(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310_API float XW310_AnalogIn(int iChannel);
/*  iChannel: 0~3, range +-10V   */
XW310_API void XW310_ReadAi(int iChannel,float *fAIValue);
/*  iChannel: 0~3, range +-10V   *///Use in the C#,the c# cannot call the function which return float value

XW310_API void XW310_AnalogOut(DWORD AoChannel,float fValue);
/*  fValue: -10.0 ~ 10.0  */

XW310_API int XW310_Read_All_DI(void);
/*  Return data = 0x00~0x07
    Return 1 => open
                Logic high level (+3.5V ~ +30V)
    Return 0 => close to GND
    Logic low level (0V ~ +1V)  */

XW310_API int XW310_Read_One_DI(int iChannel);
/*  iChannel = 0 ~ 3
    Return 1 => open
                Logic high level (+10.0V ~ +40V)
    Return 0 => close to GND
                Logic low level (0V ~ +1V)  */

XW310_API void XW310_Write_All_DO(int iOutValue);
/*  iOutValue: 0x00 ~ 0x0f  */

XW310_API void XW310_Write_One_DO(int iChannel, int iStatus);
/*  iChannel = 0 ~ 3
    iStatus = 1 => Status is ON
    iStatus = 0 => Status is OFF    */

XW310_API int XW310_Read_All_DO(void);
/*  Return data = 0x00~0x0f */

XW310_API int XW310_Read_One_DO(int iChannel);
/*  iChannel = 0 ~ 3
    Return  1 => ON
    Return  0 => OFF    */

XW310_API void XW310_SetDelay(int Delayms);
XW310_API int XW310_GetDelay(void);

XW310_API void XW310_AnanlogInSetChannel(int iChannel);
XW310_API void XW310_AnanlogOutSetChannel(int iChannel);
XW310_API int XW310_AnalogInHex(void);
XW310_API float XW310_AnalogInHexToFloat(int iValue);
XW310_API void Cslow(void);
XW310_API void usWait(unsigned usVal);

XW310_API void Test_EEPROM(void);
extern float    XW310_fAD_Gain, XW310_fAD_Offset;
extern float    XW310_fDA_Gain[2], XW310_fDA_Offset[2];

#ifdef __cplusplus
}
#endif

#endif
