#ifndef __XW310C_H
#define __XW310C_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef XW310C_EXPORTS
#define XW310C_API extern "C" __declspec(dllexport) 
#else
#define XW310C_API extern "C" __declspec(dllimport) 
#endif

#define XW310C_DigitalIn      XW310C_Read_All_DI
#define XW310C_DigitalOut     XW310C_Write_All_DO

//void XW310C_AOInit(void);

XW310C_API int XW310C_Init(void);
/*  Return value: 0   ==> success
    Return value: <>0 ==> error
    Bit0: 1 ==> Reads A/D Gain falure
    Bit1: 1 ==> Reads A/D Offset falure
    Bit2: 1 ==> Reads D/A Gain falure
    Bit3: 1 ==> Reads D/A Offset falure
    Bit4: 1 ==> WX304 board cannot be found */

XW310C_API int XW310C_GetAnanlogInType();
/*SINGLE_ENDED    0, DIFFERENTIAL    1*/
XW310C_API unsigned XW310C_GetLibVersion(void);
/*  Current version is 1.00 (return 0x0100) */

XW310C_API float XW310C_Read_AD_CalibrationGain(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310C_API float XW310C_Read_AD_CalibrationOffset(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310C_API float XW310C_Read_DA_CalibrationGain(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310C_API float XW310C_Read_DA_CalibrationOffset(int iChannel);
/*  Return 10.0 if no setting in EEPROM   */

XW310C_API float XW310C_AnalogIn(int iChannel);
/*  iChannel:DIFFERENTIAL 0~3, SINGLE_ENDED 0~7, range 0~20MA   */
XW310C_API float XW310C_ReadAi(int iChannel,float *fvalue);
/*  iChannel:DIFFERENTIAL 0~3, SINGLE_ENDED 0~7, range 0~20MA   */
//Use on the C#, when C# call c++ function return float will happen error


XW310C_API void XW310C_AnalogOut(DWORD AoChannel,float fValue);
/* AoChannel: 0~1 , fValue: 0 ~ 20.0 MA  */

XW310C_API int XW310C_Read_All_DI(void);
/*  Return data = 0x00~0x0F
    Return 1 => open
                Logic high level (+3.5V ~ +30V)
    Return 0 => close to GND
    Logic low level (0V ~ +1V)  */

XW310C_API int XW310C_Read_One_DI(int iChannel);
/*  iChannel = 0 ~ 3
    Return 1 => open
                Logic high level (+3.5V ~ +30V)
    Return 0 => close to GND
                Logic low level (0V ~ +1V)  */

XW310C_API void XW310C_Write_All_DO(int iOutValue);
/*  iOutValue: 0x00 ~ 0x0f  */

XW310C_API void XW310C_Write_One_DO(int iChannel, int iStatus);
/*  iChannel = 0 ~ 3
    iStatus = 1 => Status is ON
    iStatus = 0 => Status is OFF    */

XW310C_API int XW310C_Read_All_DO(void);
/*  Return data = 0x00~0x0f */

XW310C_API int XW310C_Read_One_DO(int iChannel);
/*  iChannel = 0 ~ 3
    Return  1 => ON
    Return  0 => OFF    */

XW310C_API void XW310C_SetDelay(int Delayms);
XW310C_API int  XW310C_GetDelay(void);

XW310C_API void XW310C_AnanlogInSetChannel(int iChannel);
//XW310C_API void XW310C_AnanlogOutSetChannel(int iChannel);
XW310C_API int XW310C_AnalogInHex(DWORD Readdelay);

//XW310C_API float XW310C_AnalogInHexToFloat(int iValue);
XW310C_API void Cslow(void);
XW310C_API void usWait(unsigned usVal);

XW310C_API void Test_EEPROM(void);
//extern float    XW310C_fAD_Gain, XW310C_fAD_Offset;
//extern float    XW310C_fDA_Gain[2], XW310C_fDA_Offset[2];

#ifdef __cplusplus
}
#endif

#endif
